'use strict';

define('swan-extension', ['swan', 'boxjs'], function (require, module, exports, define, swan, boxjs) {
  console.log('extension', swan, boxjs);

  function loadScript(path, fn) {
    var el = document.createElement('script');
    var head = document.head || document.getElementsByTagName('head')[0];
    el.onload = function () {
      el.onload = el.onerror = null;
      fn && fn();
    };
    el.onerror = function () {
      el.onload = el.onerror = null;
      console.log('loadScript', path, 'failed');
    };
    el.src = path;
    head.appendChild(el);
  }

  var id = 0;
  var createCallback = function createCallback(params) {
    // if (!params.success && !params.fail && !params.complete) return null
    var callbackName = '__wifikeyCallback__' + id++;
    window[callbackName] = function (result) {
      var ret = JSON.parse(result);
      if (+ret.status === 0) {
        params.success && params.success(ret.data);
      } else {
        params.fail && params.fail(ret.message);
      }
      params.complete && params.complete(ret.data || ret.message);
    };
    return callbackName;
  };
  // 宿主方法
  var methodArr = ['getInfo', 'signParams', 'trace', 'pay', 'shortcut', 'openAndDownloadApp', 'getTaichiConfig', 'getCdsData'];
  var hostMethodDescriptions = [];
  var methods = {};
  // 遍历声明
  methodArr.forEach(function (name) {
    // 遍历添加声明及约定参数规范
    hostMethodDescriptions.push({
      name: name,
      path: name,
      args: [{
        name: 'data',
        value: 'object'
      }, {
        name: 'cb',
        value: 'string'
      }]
    });
    // 遍历添加方法
    methods[name] = function (params) {
      return boxjs[name]({
        data: params.data || {},
        cb: createCallback(params)
      });
    };
  });

  var getShareURL = function getShareURL(_ref) {
    var appId = _ref.appId,
        scene = _ref.scene,
        target = _ref.target,
        title = _ref.title,
        content = _ref.content,
        path = _ref.path,
        imageUrl = _ref.imageUrl;

    return {
      shareUrl: 'https://a.lianwifi.com/miniapp/share/index.html',
      imageUrl: imageUrl || 'https://a.lianwifi.com/miniapp/share/img/icon.png',
      content: content || '打开WiFi万能钥匙，进入精彩世界'
    };
  };

  var components = {
    ad: {
      behaviors: ['userTouchEvents', 'animateEffect'],
      template: '\n      <wifikey-ad on-click="onClick">\n        <div s-if="rawHtml">{{rawHtml| raw}}</div>\n      </wifikey-ad>\n      ',
      depandencies: ['swaninterface'],
      initData: function initData() {
        return {
          rawHtml: null
        };
      },
      attached: function attached() {
        var ad = this;
        swan.wifikey.getInfo({
          data: {},
          complete: function complete(res) {
            var url = 'https://a.lianwifi.com/miniapp/adRender/adRender.js';
            var verCode = res.verCode || +new Date();
            // 测试版渠道
            if (res && res.chanId === 'miniprogram') {
              url = 'https://demo.lianwifi.com/miniapp/adRender/adRender.js';
            }
            url = url + '?_v=' + verCode;
            loadScript(url, function () {
              window.adRender.call(ad);
            });
          }
        });
      },
      onClick: function onClick() {
        console.log('onClick');
      }
    }
  };

  var customLog = function customLog() {};
  module.exports = {
    name: 'wifikey',
    hostMethodDescriptions: hostMethodDescriptions,
    methods: methods,
    getShareURL: getShareURL,
    customLog: customLog,
    components: components
  };
});